'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _jsxFileName = 'src/LifecyclePanel.jsx';

var _react = require('react');

var React = _interopRequireWildcard(_react);

var _reactRedux = require('react-redux');

var _constants = require('./constants');

var constants = _interopRequireWildcard(_constants);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

var LifecyclePanel = function LifecyclePanel(props) {
  var componentName = props.componentName,
      isLegacy = props.isLegacy,
      instanceId = props.instanceId,
      highlightedMethod = props.highlightedMethod,
      implementedMethods = props.implementedMethods;

  var lifecycleMethodNames = isLegacy ? constants.lifecycleMethodNamesLegacy : constants.lifecycleMethodNames;

  return React.createElement(
    'div',
    { className: 'lifecycle-panel', __source: {
        fileName: _jsxFileName,
        lineNumber: 11
      }
    },
    React.createElement(
      'div',
      { className: 'lifecycle-panel-inner', __source: {
          fileName: _jsxFileName,
          lineNumber: 12
        }
      },
      React.createElement(
        'div',
        { className: 'component-instance', __source: {
            fileName: _jsxFileName,
            lineNumber: 13
          }
        },
        componentName + '-' + instanceId
      ),
      lifecycleMethodNames.map(function (methodName) {
        return React.createElement(LifecycleMethod, {
          componentName: componentName,
          instanceId: instanceId,
          highlightedMethod: highlightedMethod,
          methodName: methodName,
          methodIsImplemented: implementedMethods.includes(methodName),
          key: methodName,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 15
          }
        });
      })
    )
  );
};

var isHighlighted = function isHighlighted(hlMethod, method) {
  return hlMethod !== null && hlMethod.componentName === method.componentName && hlMethod.instanceId === method.instanceId && hlMethod.methodName.startsWith(method.methodName) // for handling 'setState:update fn' & 'setState:callback'
  ;
};

var LifecycleMethod = function LifecycleMethod(props) {
  var highlightedMethod = props.highlightedMethod,
      componentName = props.componentName,
      instanceId = props.instanceId,
      methodName = props.methodName,
      methodIsImplemented = props.methodIsImplemented;

  var methodIsHighlighted = isHighlighted(highlightedMethod, { componentName: componentName, instanceId: instanceId, methodName: methodName });
  return React.createElement(
    'div',
    {
      className: 'lifecycle-method',
      'data-is-implemented': methodIsImplemented,
      'data-is-highlighted': methodIsHighlighted,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 41
      }
    },
    methodName
  );
};

var mapStateToProps = function mapStateToProps(_ref) {
  var logEntries = _ref.logEntries,
      highlightedIndex = _ref.highlightedIndex;
  return {
    highlightedMethod: highlightedIndex !== null && logEntries[highlightedIndex] ? logEntries[highlightedIndex] : null
  };
};

var _default = (0, _reactRedux.connect)(mapStateToProps, null, null, { storeKey: constants.reduxStoreKey })(LifecyclePanel);

exports.default = _default;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(LifecyclePanel, 'LifecyclePanel', 'src/LifecyclePanel.jsx');
  reactHotLoader.register(isHighlighted, 'isHighlighted', 'src/LifecyclePanel.jsx');
  reactHotLoader.register(LifecycleMethod, 'LifecycleMethod', 'src/LifecyclePanel.jsx');
  reactHotLoader.register(mapStateToProps, 'mapStateToProps', 'src/LifecyclePanel.jsx');
  reactHotLoader.register(_default, 'default', 'src/LifecyclePanel.jsx');
  leaveModule(module);
})();

;